@@ -14,7 +14,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(*i $Id: bitv.ml,v 1.1 2004/02/02 08:11:14 filliatr Exp $ i*)
+(*i $Id: bitv.ml,v 1.3 2004/07/13 12:54:42 filliatr Exp $ i*)
 
 (*s Bit vectors. The interface and part of the code are borrowed from the 
     [Array] module of the ocaml standard library (but things are simplified
@@ -109,7 +109,7 @@ let unsafe_set v n b =
 (*s The corresponding safe operations test the validiy of the access. *)
 
 let get v n =
-  if n < 0 or n >= v.length then invalid_arg "Bitv.set";
+  if n < 0 or n >= v.length then invalid_arg "Bitv.get";
   let (i,j) = pos n in 
   ((Array.unsafe_get v.bits i) land (Array.unsafe_get bit_j j)) > 0
 
@@ -532,7 +532,7 @@ let to_int_us v =
 let of_int_s i = 
   { length = succ bpi; bits = [| i land max_int; (i lsr bpi) land 1 |] }
 let to_int_s v = 
-  if v.length < succ bpi then invalid_arg "Bitv.to_int_us"; 
+  if v.length < succ bpi then invalid_arg "Bitv.to_int_s"; 
   v.bits.(0) lor (v.bits.(1) lsl bpi)
 
 (* [Int32] *)
@@ -553,13 +553,17 @@ let to_int32_us v =
 	Int32.of_int (v.bits.(0) land 0x7fffffff)
     | _ -> assert false
 
+(* this is 0xffffffff (ocaml >= 3.08 checks for literal overflow) *)
+let ffffffff = (0xffff lsl 16) lor 0xffff
+
 let of_int32_s i = match Sys.word_size with
   | 32 -> { length = 32; 
 	    bits = [| (Int32.to_int i) land max_int; 
 		      let hi = Int32.shift_right_logical i 30 in
 		      (Int32.to_int hi) land 3 |] }
-  | 64 -> { length = 32; bits = [| (Int32.to_int i) land 0xffffffff |] }
+  | 64 -> { length = 32; bits = [| (Int32.to_int i) land ffffffff |] }
   | _ -> assert false
+
 let to_int32_s v =
   if v.length < 32 then invalid_arg "Bitv.to_int32_s"; 
   match Sys.word_size with
@@ -567,7 +571,7 @@ let to_int32_s v =
 	Int32.logor (Int32.of_int v.bits.(0))
 	            (Int32.shift_left (Int32.of_int (v.bits.(1) land 3)) 30)
     | 64 ->
-	Int32.of_int (v.bits.(0) land 0xffffffff)
+	Int32.of_int (v.bits.(0) land ffffffff)
     | _ -> assert false
 
 (* [Int64] *)
