@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: components.mli,v 1.11 2004/02/20 14:43:45 filliatr Exp $ *)
+(* $Id: components.mli,v 1.12 2004/10/22 14:42:06 signoles Exp $ *)
 
 (** Strongly connected components *)
 
@@ -38,5 +38,8 @@ module Make (G: G) : sig
 	Beware: to be used efficiently, [scc] must be applied to a single
 	argument (the graph). *)
 
-end
+  val scc_list : G.t -> G.V.t list list
+    (** [scc_list] computes the strongly connected components of [g].
+      The result is a partition of the set of the vertices of [g]. *)
 
+end
