@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: per_imp.ml,v 1.20 2004/02/23 10:06:30 signoles Exp $ *)
+(* $Id: per_imp.ml,v 1.28 2004/11/15 16:42:07 signoles Exp $ *)
 
 (* Common implementation to persistent and imperative graphs. *)
 
@@ -70,6 +70,7 @@ end
 
 (* [HM] implementation using hashtbl. *)
 module Make_Hashtbl(X: COMPARABLE) = struct
+
   include Hashtbl.Make(X)
   type 'a return = unit
 
@@ -97,7 +98,7 @@ module Make_Hashtbl(X: COMPARABLE) = struct
     let h' = create ()  in
     iter (fun k v -> let k, v = f k v in add k v h') h;
     h'
-    
+
 end
 
 (* [HM] implementation using map *)
@@ -138,7 +139,9 @@ struct
 
   let pred g v = fold_pred (fun v l -> v :: l) g v []
 
-  let in_degree g v = fold_pred (fun v n -> n + 1) g v 0
+  let in_degree g v = 
+    if not (mem_vertex v g) then invalid_arg "in_degree";
+    fold_pred (fun v n -> n + 1) g v 0
 
   let iter_pred_e f g v =
     if not (mem_vertex v g) then invalid_arg "iter_pred_e";
@@ -155,6 +158,8 @@ end
 (* Common implementation to all (directed) graph implementations. *)
 module Minimal(S: Set.S)(HM: HM) = struct
 
+  type vertex = HM.key
+
   let is_directed = true
   let empty = HM.empty
   let create = HM.create
@@ -162,16 +167,17 @@ module Minimal(S: Set.S)(HM: HM) = struct
 
   let nb_vertex g = HM.fold (fun _ _ -> succ) g 0
   let nb_edges g = HM.fold (fun _ s n -> n + S.cardinal s) g 0
-  let out_degree g v = S.cardinal (HM.find v g)
+  let out_degree g v = 
+    S.cardinal (try HM.find v g with Not_found -> invalid_arg "out_degree")
 
-  let mem_vertex g v1 = HM.mem v1 g
+  let mem_vertex g v = HM.mem v g
 
   let unsafe_add_vertex g v = HM.add v S.empty g
   let unsafe_add_edge g v1 v2 = HM.add v1 (S.add v2 (HM.find v1 g)) g
 
   let iter_vertex f = HM.iter (fun v _ -> f v)
-  let fold_vertex f = HM.fold (fun v _ a -> f v a)
-
+  let fold_vertex f = HM.fold (fun v _ -> f v)
+    
 end
 
 (* Common implementation to all the unlabeled (directed) graphs. *)
@@ -189,6 +195,8 @@ module Unlabeled(V: COMPARABLE)(HM: HM with type key = V.t) = struct
     let create v1 () v2 = v1, v2
   end
 
+  type edge = E.t
+
   let mem_edge g v1 v2 = 
     try
       S.mem v2 (HM.find v1 g)
@@ -252,6 +260,8 @@ struct
       C.compare (x1, (x2, x3)) (y1, (y2, y3))
   end
 
+  type edge = E.t
+
   let mem_edge g v1 v2 = 
     try
       S.exists (fun (v2', _) -> V.equal v2 v2') (HM.find v1 g)
@@ -274,7 +284,7 @@ struct
 		 (HM.find_and_raise v1 g "remove_edge")) g
 
   let remove_edge_e g (v1, l, v2) = 
-    if not (HM.mem v2 g) then invalid_arg "remove_edge";
+    if not (HM.mem v2 g) then invalid_arg "remove_edge_e";
     HM.add v1 (S.remove (v2, l) (HM.find_and_raise v1 g "remove_edge_e")) g
 
   let iter_succ f g v = 
@@ -351,8 +361,11 @@ module Make_Abstract(G: Sig.G) = struct
 	   imperative and persistent implementation.
 	   Do not modify size in the persistent implementation ! *)
 
+    type vertex = G.vertex
+    type edge = G.edge
+
     module PV = G.V
-    module PE = struct include G.E type vertex = PV.t end
+    module PE = G.E
 
     let iter_edges f g = G.iter_edges f g.edges
     let fold_edges f g = G.fold_edges f g.edges
@@ -368,11 +381,12 @@ module Make_Abstract(G: Sig.G) = struct
 
   let is_empty g = g.size = 0
   let nb_vertex g = g.size
-  let out_degree g v = G.out_degree g.edges v
-  let in_degree g v = G.in_degree g.edges v
 
   (* redefinitions *)
 
+  let out_degree g = G.out_degree g.edges
+  let in_degree g = G.in_degree g.edges
+
   let nb_edges g = G.nb_edges g.edges
   let succ g = G.succ g.edges
   let mem_vertex g = G.mem_vertex g.edges
@@ -397,7 +411,7 @@ module Make_Abstract(G: Sig.G) = struct
 end
 
 (* Build persistent (resp. imperative) graphs from a persistent (resp. 
-   imperative association table) *)
+   imperative) association table *)
 module Make(F : functor(X: COMPARABLE) -> HM with type key = X.t) = struct
 
   module Digraph = struct
@@ -448,6 +462,7 @@ module Make(F : functor(X: COMPARABLE) -> HM with type key = X.t) = struct
       include Make_Abstract(struct type return = S.t HM.return include G end)
 *)
       include Make_Abstract(G)
+
       (* JS: 
 	 2 lignes suivantes  supprimer quand la factorisation sera possible *)
       let remove_edge g = G.remove_edge g.edges
@@ -498,7 +513,7 @@ end
 
 module Graph = struct
 
-  (* Predecessors are the successors in a undirected graph. *)
+  (* Predecessors are the successors in an undirected graph. *)
   module Pred(S: sig
 		module PV : VERTEX
 		module PE : EDGE
@@ -529,7 +544,7 @@ module Graph = struct
 
       include G
       module PV = V
-      module PE = struct type vertex = V.t include E end
+      module PE = E
 		    
       let is_directed = false
 			  
@@ -580,7 +595,6 @@ module Graph = struct
     end
 
     include M
-
     include Pred(M)
 
   end
@@ -592,7 +606,7 @@ module Graph = struct
       include G
 
       module PV = V
-      module PE = struct type vertex = V.t include E end
+      module PE = E
 
       let is_directed = false
 
@@ -615,8 +629,8 @@ module Graph = struct
 	     if tag (E.src e) <= tag (E.dst e) then f e acc else acc)
 	  
     end
-    include M
 
+    include M
     include Pred(M)
 
   end
