@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: util.ml,v 1.12 2004/02/05 10:06:02 signoles Exp $ *)
+(* $Id: util.ml,v 1.14 2004/10/19 15:21:45 signoles Exp $ *)
 
 open Sig
 
@@ -42,8 +42,26 @@ module HTProduct(X: HASHABLE)(Y: HASHABLE) = struct
 end
 
 module CMPProduct(X: COMPARABLE)(Y: COMPARABLE) = struct 
-
   include HTProduct(X)(Y)
   include (OTProduct(X)(Y): sig val compare : t -> t -> int end)
-      
 end
+
+module DataV(L : sig type t end)(V : Sig.COMPARABLE) = 
+struct
+  type data = L.t
+  type label = V.t
+  type t = data ref * V.t
+      
+  let compare ((_, x) : t) ((_, x') : t) =
+    V.compare x x'
+      
+  let hash ((_, x) : t) = V.hash x
+
+  let equal ((_, x) : t) ((_, x') : t) = V.equal x x'
+				   
+  let create y lbl = (ref y, lbl)
+  let label (_, z) = z
+  let data (y, _) = !y
+  let set_data (y, _) = (:=) y
+end
+
