@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: util.mli,v 1.10 2004/02/05 10:04:02 signoles Exp $ *)
+(* $Id: util.mli,v 1.11 2004/06/28 07:32:55 filliatr Exp $ *)
 
 open Sig
 
@@ -27,3 +27,21 @@ module HTProduct(X: HASHABLE)(Y: HASHABLE) :
 
 module CMPProduct(X: COMPARABLE)(Y: COMPARABLE) : 
   COMPARABLE with type t = X.t * Y.t
+
+(** Create a vertex type with some data attached to it *)
+module DataV :
+  functor (L : sig type t end) ->
+  functor (V : Sig.COMPARABLE) ->
+sig
+  type data = L.t
+  and label = V.t
+  and t = data ref * V.t
+  val compare : t -> t -> int
+  val hash : t -> int
+  val equal : t -> t -> bool
+  val create : data -> V.t -> t
+  val label : t -> V.t
+  val data : t -> data
+  val set_data : t -> data -> unit
+end
+  
